# vim: set sw=4 ts=4 et nu:
#
# spec file for package userspace-rcu
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           userspace-rcu
Version:        0.8.7
Release:        2.3
%define soname      2
Summary:        Userspace Read-Copy-Update Library
License:        LGPL-2.1+ and MIT and GPL-2.0+ and GPL-3.0+
Group:          System/Libraries
Source0:        http://lttng.org/files/urcu/userspace-rcu-%{version}.tar.bz2
Source1:        http://lttng.org/files/urcu/userspace-rcu-%{version}.tar.bz2.asc
Source2:        userspace-rcu.keyring
Patch1:         userspace-rcu-aarch64.patch
Url:            http://lttng.org/urcu
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  automake
BuildRequires:  gcc
BuildRequires:  glibc-devel
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  pkgconfig

%description
liburcu is a LGPLv2.1 userspace RCU (read-copy-update) library. This data
synchronization library provides read-side access which scales linearly with
the number of cores. It does so by allowing multiples copies of a given data
structure to live at the same time, and by monitoring the data structure
accesses to detect grace periods after which memory reclamation is possible.

%package -n liburcu%{soname}
Summary:        Userspace Read-Copy-Update Library
Group:          System/Libraries

%description -n liburcu%{soname}
liburcu is a LGPLv2.1 userspace RCU (read-copy-update) library. This data
synchronization library provides read-side access which scales linearly with
the number of cores. It does so by allowing multiples copies of a given data
structure to live at the same time, and by monitoring the data structure
accesses to detect grace periods after which memory reclamation is possible.

%package -n liburcu-devel
Summary:        Userspace Read-Copy-Update Library
Group:          Development/Libraries/C and C++
Requires:       liburcu%{soname} = %{version}

%description -n liburcu-devel
liburcu is a LGPLv2.1 userspace RCU (read-copy-update) library. This data
synchronization library provides read-side access which scales linearly with
the number of cores. It does so by allowing multiples copies of a given data
structure to live at the same time, and by monitoring the data structure
accesses to detect grace periods after which memory reclamation is possible.

%prep
%setup -q
%patch1 -p1

%build
autoreconf -fi
%configure --disable-silent-rules --disable-static
%__make %{?_smp_mflags}

%install
%makeinstall

rm -rf "%{buildroot}%{_datadir}/doc"
rm "%buildroot/%_libdir"/*.la

%post   -n liburcu%{soname} -p /sbin/ldconfig
%postun -n liburcu%{soname} -p /sbin/ldconfig

%files -n liburcu%{soname}
%defattr(-,root,root)
%doc ChangeLog LICENSE README *.txt doc/*.txt
%{_libdir}/liburcu.so.%{soname}
%{_libdir}/liburcu.so.%{soname}.*
%{_libdir}/liburcu-bp.so.%{soname}
%{_libdir}/liburcu-bp.so.%{soname}.*
%{_libdir}/liburcu-cds.so.%{soname}
%{_libdir}/liburcu-cds.so.%{soname}.*
%{_libdir}/liburcu-common.so.%{soname}
%{_libdir}/liburcu-common.so.%{soname}.*
%{_libdir}/liburcu-mb.so.%{soname}
%{_libdir}/liburcu-mb.so.%{soname}.*
%{_libdir}/liburcu-qsbr.so.%{soname}
%{_libdir}/liburcu-qsbr.so.%{soname}.*
%{_libdir}/liburcu-signal.so.%{soname}
%{_libdir}/liburcu-signal.so.%{soname}.*

%files -n liburcu-devel
%defattr(-,root,root)
%{_includedir}/urcu*.h
%{_includedir}/urcu
%{_libdir}/liburcu.so
%{_libdir}/liburcu-bp.so
%{_libdir}/liburcu-cds.so
%{_libdir}/liburcu-common.so
%{_libdir}/liburcu-mb.so
%{_libdir}/liburcu-qsbr.so
%{_libdir}/liburcu-signal.so
%{_libdir}/pkgconfig/liburcu.pc
%{_libdir}/pkgconfig/liburcu-bp.pc
%{_libdir}/pkgconfig/liburcu-cds.pc
%{_libdir}/pkgconfig/liburcu-mb.pc
%{_libdir}/pkgconfig/liburcu-qsbr.pc
%{_libdir}/pkgconfig/liburcu-signal.pc

%changelog
* Tue Sep 29 2015 dmueller@suse.com
- remove dependency on gpg-offline, is done by source validator
- drop userspace-rcu-ppc64le.patch, included in
  userspace-rcu-aarch64.patch
* Mon Aug 31 2015 dmueller@suse.com
- add userspace-rcu-aarch64.patch (fate#318370)
  enables build for aarch64
* Tue Jul 28 2015 tonyj@suse.com
- Update to version 0.8,7 (FATE#319273)
  Changelog 0.8.7:
  * Fix: deadlock when thread join is issued in read-side C.S.
  * Fix: rename RCU_DEBUG to DEBUG_RCU in urcu-qsbr.h
  * Mark braced-groups within expressions with __extension__
  * Fix: compat_futex_noasync race condition
  * Fix: documentation: urcu-pointer.h: s/rcu_dereference_pointer/rcu_dereference/
  * Fix: call rcu should call internal RCU API
* Mon Nov 24 2014 mq@suse.cz
- updated to 0.8.6:
  * Fix: silence gcc -Wextra warning
  * compiler: use __GNUC__ instead of the undefined __GNUC_MAJOR__
  * Fix: lfstack reversed empty/non-empty return value
  * lfstack: fix: add missing __cds_lfs_init
  * Fix: preserve example files' timestamps when copying
  * rculfhash: remove duplicated code
  * rculfhash: handle pthread_create failures
  * rculfhash: fall back to single-threaded resize on calloc failure
  * x86: drop extra semi-colon in caa_cpu_relax
  * Fix: Use after free in rcu_barrier()
  * Fix: rcu_barrier(): uninitialized futex field
  * call_rcu threads should clear their PAUSED flag when they unpause
  * Fix: bring back dummy rcu_bp_exit symbol
* Fri Mar 28 2014 pgajdos@suse.com
- updated to 0.8.4:
  * Fix: move wait loop increment before first conditional block
  * Fix: high cpu usage in synchronize_rcu with long RCU read-side C.S.
  * Fix: out of tree build: doc/examples
  * Fix: out of tree build tests/common
  * tests/unit: use lib rather than source
  * automake: Rename INCLUDES to AM_CPPFLAGS (new name)
  * tests regressions: use lib rather than recompile from source
  * tests: use common lib rather than recompile compat sources
  * urcu tests: use lib rather than compile from source
  * urcu mb tests: use lib rather than recompile from source
  * urcu signal tests: use library rather than recompile source
  * tests: move yield debug to common test library
  * tests urcu bp: use lib rather than recompile source
  * test_urcu_defer: link on urcu lib rather than recompile source
  * tests/benchmark: use urcu qsbr lib rather than recompile from source
  * Pass the CC variable to the example Makefiles
  * Fix: urcu-bp interaction with threads vs constructors/destructors
  * Fix undefined NULL pointer arithmetic
  * Blacklist ARM gcc 4.8.0, 4.8.1, 4.8.2
  * rculfhash: document max_nr_buckets = 0
* Tue Dec  3 2013 dvaleev@suse.com
- Fix build on ppc64le platform
- added patches:
  * userspace-rcu-ppc64le.patch
* Tue Nov 26 2013 pgajdos@suse.com
- updated to 0.8.1:
  * tls-compat: fix comment typo
  * Keep ABI compatible with already compiled LGPL applications
  * Fix: tls-compat multi-lib conflict
  * Use cross compiler for doc examples
  * gcc warning fixes: -Wsign-compare and -Wextra
  * Fix: urcu-qsbr: reversed logic on RCU_DEBUG
  * Fix: urcu-bp segfault in glibc pthread_kill()
  * Fix urcu-bp: don't move registry
  * Fix: compat futex duplicated lock and completion
  * Fix: i386 compat code duplicated mutex instances
  * Fix: urcu-bp: Bulletproof RCU arena resize bug
  * Fix: test_mutex.c uninitialized mutex
* Mon Sep  9 2013 pgajdos@suse.com
- updated to 0.8.0:
  * Fix: hash table growth (for small tables) should be limited
  * Fix: doc/examples cross-build
  * Introduce URCU_INLINE_SMALL_FUNCTIONS
  * etc., see ChangeLog
- gpg-offline
* Wed Mar 27 2013 pgajdos@suse.com
- updated to 0.7.6:
  * Discourage use of pthread_atfork() for call_rcu handlers
  * Fix call_rcu fork handling
  * test: fork handling
  * Fix TLS detection: test with linker, add --disable-compiler-tls
  * Cleanup: cast pthread_self() return value to unsigned long
  * Fallback mechanism not working on platform where TLS is unsupported
* Tue Nov 20 2012 pgajdos@suse.com
- updated to 0.7.5:
  * 19cf3ae Fix: call_rcu list corruption on teardown
  * Ensure that read-side functions meet 10-line LGPL criterion
  * tls-compat.h: document sigaltstack(2) limitation
  * urcu: add notice to URCU_TLS() for it is not strictly async-signal-safe
  * Document sigaltstack(2) limitation
  * Documentation: update LICENSE file
* Wed Aug 29 2012 cfarrell@suse.com
- license update: LGPL-2.1+ and MIT and GPL-2.0+
  See LICENSE file
* Tue Aug 28 2012 pascal.bleser@opensuse.org
- update to 0.7.4:
  * Fix: rculfhash should be offline while waiting for resize to complete
  * urcu: move busy-wait code and name it ___cds_wfq_node_sync_next()
  * urcu: fix compat_futex_noasync()
  * urcu: add hint to DEFINE_URCU_TLS() for compound types
  * Fix: CAA_BUILD_BUG_ON should refer to CAA_BUILD_BUG_ON_ZERO
  * Add MIPS support
  * Fix inappropriate lib behavior: don't call exit()
  * Fix: re-enable compatibility with autoconf < 2.64
  * Fix c99 compatibility: use __asm__ and __volatile__ in public headers
  * Fix c99 compatibility: use __typeof__ instead of typeof in public headers
- changes from 0.7.1:
  * fix: uatomic_set return value compile fix for non-x86 arch
- changes from 0.7.0:
  * Update return value of "set" operations
  * rculfhash: document implied memory barriers
  * rculfhash: Ensure future-proof memory barrier semantic consistency
  * uatomic: add memory barrier API for and/or/add/sub/inc/sub
  * rculfhash: fix: race between replace and del operations
  * rculfhash: replace unneeded rcu_dereference by CMM_LOAD_SHARED
  * rculfhash: check malloc NULL pointer
  * Fix uatomic sign cast
  * Remove unused jhash.h file
  * RCU lock-free hash table: implement cds_lfht_is_node_deleted()
  * rculfhash: remove an invocation of bit_reverse_ulong() when adding
  * cds_lfht_replace: add checks for old/new node hash/value match
  * Add missing REMOVAL_OWNER_FLAG comment to cds_lfht_node comment
  * _cds_lfht_del is not used for buckets anymore, remove parameter
  * rculfhash: Relax atomicity guarantees required by removal operation
  * simplify the deletion for bucket node
  * Cleanup DEFINE_RCU_FLAVOR()
  * Add cds_lfht_ prefix to fls_ulong, get_count_order_ulong, get_count_order_u32
  * Merge RCU Lock-Free Resizable Hash Table
* Wed May 23 2012 jengelh@inai.de
- Exclusively ship shared library
- Strip redundant tags/sections from specfile
* Thu Mar 29 2012 pascal.bleser@opensuse.org
- initial version (0.6.7)
